__version__ = "V1.0"
__contributors__ = "Gotam Dahiya, Manya Chadha"
__documentation__ = "https://github.com/KawaSpaceOrg/kawaplatformlibrary/wiki"
__homepage__ = "https://github.com/KawaSpaceOrg/kawaplatformlibrary" 